@@ -125,7 +125,6 @@ public:
     void unmanageClient(YFrameClient *client);
     void clientDestroyed(YFrameClient* client);
     void clientTransfered(YFrameClient* client, YFrameWindow* frame);
-    void destroyedClient(Window win);
     void mapClient(Window win);
 
     void setFocus(YFrameWindow *f, bool canWarp = false, bool reorder = true);
@@ -182,8 +181,6 @@ public:
     bool focusTop(YFrameWindow *f);
     void updateClientList();
     void updateUserTime(const UserTime& userTime);
-
-    int windowCount(int workspace);
     void popupWindowListMenu(YWindow *owner, int x, int y);
 
     void initWorkspaces();
@@ -332,6 +329,7 @@ private:
     };
 
     bool ignoreOverride(Window win, const XWindowAttributes& attr, int* layer);
+    bool isManageable(Window win, bool mapClient);
     bool tabbingClient(YFrameClient* client);
     YFrameClient* allocateClient(Window win, bool mapClient);
     YFrameWindow* allocateFrame(YFrameClient* client);
@@ -339,6 +337,7 @@ private:
     bool handleWMKey(const XKeyEvent &key, KeySym k, unsigned vm);
     void setWmState(WMState newWmState);
     void refresh();
+    void focusOverlap();
 
     IApp *app;
     YActionListener *wmActionListener;
